@@ -6,19 +6,18 @@ from baseWindow import BaseWindow
 from volumeControl import VolumeControl
 from playerControl import PlayerControl
 from util import utils, settings
+import status
 
 class AudioPanel(BaseWindow):
-    def __init__(self, screen):
+    def __init__(self):
         """
         Upper left panel - only shows when Awake.  Will always show the
         volume slider, and will only show the player controls if there is
         a controllable mpris player available.
         """
         super(AudioPanel, self).__init__()
-        self.set_transition_type(Gtk.RevealerTransitionType.SLIDE_DOWN)
 
-        self.screen = screen
-        self.monitor_index = self.screen.get_primary_monitor()
+        self.monitor_index = status.screen.get_primary_monitor()
 
         self.update_geometry()
 
@@ -47,4 +46,4 @@ class AudioPanel(BaseWindow):
         if should_show:
             self.show_all()
         else:
-            self.disabled = True
\ No newline at end of file
+            self.disabled = True
